@@ -40,7 +40,7 @@ class TargetKind(Enum):
             TargetKind.STATIC_LIB: "rapid_static_lib",
             TargetKind.DYNAMIC_LIB: "rapid_dynamic_lib",
             TargetKind.EXECUTABLE: "rapid_exe",
-        }[self.value]
+        }[self]
 
 
 BUILD_TYPE_DEBUG = "debug"
